@@ -85,7 +85,7 @@ class Mysql(object):
         result_list = cls.convert_tuple_to_dict(records=records, column_names=column_names)
         return result_list
 
-    def execute_sql(self, sql: str, action: str):
+    def execute_sql(self, sql: str, action: str, is_need_close: bool = True) -> list:
         results = None
         if self.conn and self.conn.is_connected():
             cursor: CMySQLCursor = self.conn.cursor()
@@ -104,8 +104,9 @@ class Mysql(object):
                     logger.error(e)
             else:
                 pass
-            cursor.close()
-            self.conn.close()
+            if is_need_close is True:
+                cursor.close()
+                self.conn.close()
         else:
             logger.error("当前连接不正常.")
         return results
