@@ -10,9 +10,13 @@
 # ---------------------------------------------------------------------------------------------------------
 """
 from redis import ConnectionPool, Redis
+from middleware_helper.network import filter_system_port_list
 
 
 def get_redis_pool(**redis_params_map) -> ConnectionPool:
+    port = redis_params_map.get("port")
+    if isinstance(port, list):
+        redis_params_map["port"] = filter_system_port_list(data_port=port, default_port=6379)
     return ConnectionPool(
         host=redis_params_map.get("host"),
         password=redis_params_map.get("password"),
